BarChart<T> class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- BarChart
Constructors
-
BarChart({required List<
T> listBar, double paddingBottom = 0, double paddingTop = 0, double barWidth = 20, double barMargin = 20, double barPaddingLeft = 30, TextStyle indicatorTextStyle = kIndicatorTextStyle, TextStyle titleTextStyle = kTitleTextStyle, BoxDecoration barDecoration = kDefaultBarDecoration, Color lineColor = Colors.grey, required TitleFunc<T> indicatorBuilder, required TitleFunc<T> getTitle, required ValueFunc<T> getValue, required LineTextFormat lineTextFormat, OnBarTapFunc<T> ? onBarTap, Key? key}) -
const
Properties
- barDecoration → BoxDecoration
-
Style of bar chart
final
- barMargin → double
-
final
- barPaddingLeft → double
-
final
- barWidth → double
-
final
-
getTitle
→ TitleFunc<
T> -
Function to get Title of Bar Chart
final
-
getValue
→ ValueFunc<
T> -
Function to get Value of Bar Chart
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
indicatorBuilder
→ TitleFunc<
T> -
Builder for value on the top of Barchart when tapped
final
- indicatorTextStyle → TextStyle
-
Text style of indicator
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lineColor → Color
-
Indicator line Color
final
- lineTextFormat → LineTextFormat
-
Function for format indicator line in the background of
final
-
listBar
→ List<
T> -
final
-
onBarTap
→ OnBarTapFunc<
T> ? -
final
- paddingBottom → double
-
final
- paddingTop → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleTextStyle → TextStyle
-
Text style of title
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< BarChart< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited